package com.me.pacman.entity;

import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.me.pacman.entity.ai.Behaviour;
import com.me.pacman.entity.ai.Target;
import com.me.pacman.state.PlayState;

public class Ghost extends MovableEntity {

    private PlayState state;

    public Behaviour currentBehaviour;

    public Behaviour chaseBehaviour;
    public Behaviour freightBehaviour;
    public Behaviour scatterBehaviour;

    public TextureRegion[][] sprite;

    private int spriteIndex;
    private int counter = 0;

    public Ghost(PlayState state, float x, float y, Direction direction, int spriteIndex,
                 Behaviour chaseBehaviour, Behaviour freightBehaviour, Behaviour scatterBehaviour) {
        super(state, x, y, 7.33f, true, direction, 0.1f);
        this.state = state;
        this.spriteIndex = spriteIndex;
        this.chaseBehaviour = chaseBehaviour;
        this.freightBehaviour = freightBehaviour;
        this.scatterBehaviour = scatterBehaviour;
        sprite = state.getGame().assets.ghosts;
    }

    @Override
    public TextureRegion getSprite() {
        return sprite[2 + (counter % 2)][spriteIndex];
    }

    @Override
    public void render(SpriteBatch batch, int offsetX, int offsetY) {
        super.render(batch, offsetX, offsetY);

        // draw eyes so the ghost can see
        batch.draw(sprite[1][currDirection.ordinal()], (int) (x * 8) + (offsetX - 8), (y * 8) + (offsetY - 8));
    }

    @Override
    public void update(float dt) {
        super.update(dt);

        if (!state.paused && age % 20 == 0) {
            counter++;
        }
    }

    private class ReturnToBase extends Behaviour {

        final Target home = new Target(14, 16);

        public ReturnToBase(PlayState state) {
            super(state);
        }

        @Override
        public Target getTarget() {
            return home;
        }

    }

}
