package com.me.pacman.entity;

import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.me.pacman.level.LevelTile;
import com.me.pacman.state.PlayState;

public class Pacman extends MovableEntity {

    private TextureRegion[][] sprite;
    private TextureRegion[][] death;

    private PlayState state;
    private int counter = 1;

    private int freezeFrames = 0;

    public boolean alive = true;
    public int deathFrame = 0;

    public Pacman(PlayState state, boolean moving) {
        super(state, 14, 7.5f, 7.5f, moving, Direction.LEFT, 0.3f);
        this.state = state;
        sprite = state.getGame().assets.pacman;
        death = state.getGame().assets.deathAnimation;
    }

    @Override
    public TextureRegion getSprite() {
        if (!alive) {
            return death[deathFrame / 4][deathFrame % 4];
        }

        if (!moving) {
            return sprite[2][0];
        }

        return sprite[currDirection.ordinal()][canMove ? counter % 3 : 1];
    }

    @Override
    public void update(float dt) {
        if (freezeFrames > 0) {
            freezeFrames--;
            return;
        }

        super.update(dt);

        if (!state.paused && canMove && age % 4 == 0) {
            counter += 1;
        }

        if (age % 8 == 0 && !alive) {
            deathFrame++;
        }

        LevelTile tile = state.level.getTile(x, y);
        if (tile == null) {
            return;
        }

        switch (tile) {
            case PELLET:
                state.eatPellet(x, y);
                freezeFrames = 1;
                break;
            case POWER_PELLET:
                state.eatPowerPellet(x, y);
                freezeFrames = 3;
                break;
        }
    }

}
